Index: lib/requestBlocker.js |
=================================================================== |
--- a/lib/requestBlocker.js |
+++ b/lib/requestBlocker.js |
@@ -65,20 +65,21 @@ |
for (let type in browser.webRequest.ResourceType) |
yield resourceTypes.get(browser.webRequest.ResourceType[type]) || "OTHER"; |
// WEBRTC gets addressed through a workaround, even if the webRequest API is |
// lacking support to block this kind of a request. |
yield "WEBRTC"; |
// POPUP, CSP and ELEMHIDE filters aren't mapped to resource types. |
yield "POPUP"; |
yield "ELEMHIDE"; |
yield "CSP"; |
+ yield "REWRITE"; |
}()); |
function getDocumentInfo(page, frame, originUrl) |
{ |
return [ |
extractHostFromFrame(frame, originUrl), |
getKey(page, frame, originUrl), |
!!checkWhitelisted(page, frame, originUrl, |
@@ -189,16 +190,33 @@ |
return; |
let type = resourceTypes.get(details.type) || "OTHER"; |
let [docDomain, sitekey, specificOnly] = getDocumentInfo(page, frame, |
originUrl); |
let [filter, urlString, thirdParty] = matchRequest(url, type, docDomain, |
sitekey, specificOnly); |
+ if (filter instanceof BlockingFilter && filter.rewrite) |
+ { |
+ let rewritten = filter.doRewrite(urlString); |
+ if (rewritten && rewritten != urlString) |
+ { |
+ getRelatedTabIds(details).then(tabIds => |
+ { |
+ logRequest(tabIds, urlString, "REWRITE", docDomain, |
+ thirdParty, sitekey, specificOnly, filter); |
+ }); |
+ |
+ return {redirectUrl: rewritten}; |
+ } |
+ // we couldn't do the rewrite, so just let it through. |
+ return; |
+ } |
+ |
getRelatedTabIds(details).then(tabIds => |
{ |
logRequest(tabIds, urlString, type, docDomain, |
@@ -65,20 +65,21 @@ |
// lacking support to block this kind of a request. |
yield "WEBRTC"; |
- // POPUP, CSP and ELEMHIDE filters aren't mapped to resource types. |
+ // POPUP, CSP, REWRITE and ELEMHIDE filters aren't mapped to resource types. |
yield "POPUP"; |
yield "ELEMHIDE"; |
thirdParty, sitekey, specificOnly, filter); |
}); |
if (filter instanceof BlockingFilter) |
return {cancel: true}; |